@@ -1,6 +1,6 @@
 package CatalystX::Usul;
 
-# @(#)$Id: Usul.pm 426 2009-04-01 15:53:30Z pjf $
+# @(#)$Id: Usul.pm 437 2009-04-07 21:05:27Z pjf $
 
 use strict;
 use warnings;
@@ -12,7 +12,7 @@ use IPC::SRLock;
 use Module::Pluggable::Object;
 use Text::Markdown qw(markdown);
 
-use version; our $VERSION = qv( sprintf '0.1.%d', q$Rev: 426 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.1.%d', q$Rev: 437 $ =~ /\d+/gmx );
 
 __PACKAGE__->mk_accessors( qw(content_type debug encoding lock log
                               messages prefix redirect_to secret suid
@@ -234,7 +234,7 @@ CatalystX::Usul - A base class for Catalyst MVC components
 
 =head1 Version
 
-0.1.$Revision: 426 $
+0.1.$Revision: 437 $
 
 =head1 Synopsis
 
@@ -396,8 +396,10 @@ Returns an array ref of available plugins
 
    $uri = $self->uri_for( $c, $action_path, @args );
 
-Provide defaults for the L<uri_for|Catalyst/uri_for> method. Search
-for the uri with increasing numbers of capture args
+Turns the action path into an action object by calling L</get_action>.
+Calculates the number of capture args by introspecting the dispatcher
+spilts them of from passed args and then calls
+L<uri_for|Catalyst/uri_for>
 
 =head2 _lock_obj
 
@@ -477,3 +479,4 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE
 # mode: perl
 # tab-width: 3
 # End:
+
